{ config, lib, pkgs, ... }:

{
  imports = [
    ./hardware.nix
  ];

  hm.home.packages = with pkgs; [
    # archives
    zip xz unzip p7zip zstd
    # utils
    ffmpeg ripgrep jq libqalculate imagemagick
    # dev
    sqlitebrowser sqlite-analyzer
    # nix
    nix-output-monitor nix-prefetch-scripts nix-top
    # system
    btop duf lm_sensors ethtool pciutils usbutils powertop killall
    # debug
    strace ltrace lsof helvum
    # apps
    firefox qalculate-gtk krita inkscape onlyoffice-desktopeditors vlc nicotine-plus transmission_4-gtk font-manager obs-studio imhex pwvucontrol nautilus gnome-disk-utility gnome-text-editor baobab file-roller gnome-system-monitor loupe gnome-weather kdePackages.kdenlive
    # compatibility
    wineWowPackages.waylandFull winetricks
    # misc
    bat file which packwiz yt-dlp fastfetch hyfetch trashy wev
    # games
    prismlauncher
  ] ++ (with pkgs.my; [
    # none yet
  ]);

  modules = {
    security.useDoas = true;

    hardware = {
      bluetooth.enable = true;
      pipewire.enable = true;
      print.enable = true;
      pointer.enable = true;
      tablet.enable = true;
    };
    dev = {
      enable = true;
    };
    desktop = {
      # set to `x11` or `wayland`, improves compat
      envProto = "wayland";

      # window manager / desktop environment
      niri.enable = true;

      # accessories
      hyprlock.enable = true;
      hypridle.enable = true;
      swww.enable = true;
      gnome-keyring.enable = true;
      mate-polkit.enable = true;
      dunst.enable = true;
      rofi.enable = true;
      fuzzel.enable = true;
      waybar.enable = true;
      batsignal.enable = true;
      wob.enable = true;
      gammastep.enable = true;
      cliphist.enable = true;
      xwayland-satellite.enable = true;
      wl-clip-persist.enable = true;

      # display manager
      regreet.enable = true;

      # theme, see `modules/desktop/themes`
      themes.active = "catppuccin";

      # monitors, see `modules/desktop/monitors`
      monitors.enable = true;
      monitors.monitors = [
        { name = "eDP-1"; scale = 2.0; }
      ];
    };
    software = {
      # system
      system.eza.enable = true;
      system.wezterm.enable = true;
      system.fish.enable = true;
      system.syncthing.enable = true;
      system.flatpak.enable = true;
      system.mpv.enable = true;
      system.ananicy.enable = true;
      # editors
      editors.micro.enable = true;
      editors.vscode.enable = true;
      # dev
      dev.git.enable = true;
      # distractions
      distractions.discord.enable = true;
      distractions.discord.vesktop = true;
      distractions.steam.enable = true;
      distractions.steam.useGamescope = true;
      # tools
      tools.gpg.enable = true;
      tools.rbw.enable = true;
      tools.noisetorch.enable = true;
    };
  };
}
