{ lib, config, pkgs, system, inputs , ... }:

with lib;
let
  cfg = config.modules.desktop.hypridle;
in {
  options.modules.desktop.hypridle = {
    enable = mkEnableOption "Enable hypridle, a wayland idle daemon";
    package = mkOption {
      type = types.package;
      default = inputs.hypridle.packages.${system}.hypridle;
      example = "pkgs.hypridle";
    };
    desktop = mkEnableOption "Enable desktop tweaks (greatly extends the idle timeout)";
    desktopMultiplier = mkOption {
      type = types.int;
      default = 10;
      example = 10;
    };
  };

  config = mkIf cfg.enable {
    hm.home.packages = [ cfg.package ];
    hm.services.hypridle = {
      enable = true;
      package = cfg.package;

      settings = {
        general = {
          lock_cmd = "${pkgs.procps}/bin/pidof hyprlock || ${lib.getExe config.modules.desktop.hyprlock.package}";
          unlock_cmd = "${pkgs.procps}/bin/pkill -USR1 hyprlock";

          before_sleep_cmd = "${pkgs.systemd}/bin/loginctl lock-session"; # lock the screen before sleeping
        };

        listener = let
          toDesktopTimeout = t: if cfg.desktop then t * cfg.desktopMultiplier else t;
        in [
          {
            timeout = toDesktopTimeout 60; # 1 min
            on-timeout = "${lib.getExe pkgs.brightnessctl} -c backlight -s set 20"; # dim screen, save brightness state
            on-resume = "${lib.getExe pkgs.brightnessctl} -c backlight -r"; # restore previous screen brightness state
          }
          {
            timeout = toDesktopTimeout 60; # 1 min
            on-timeout = "${lib.getExe pkgs.brightnessctl} -d '*:kbd_backlight' -s set 0"; # turn off keyboard backlight, save state
            on-resume = "${lib.getExe pkgs.brightnessctl} -d '*:kbd_backlight' -r"; # restore previous keyboard backlight state
          }
          {
            timeout = toDesktopTimeout (60 * 2); # 2 min
            on-timeout = "${pkgs.systemd}/bin/loginctl lock-session"; # lock computer
          }
          {
            timeout = toDesktopTimeout (60 * 15); # 15 min
            on-timeout = "${pkgs.systemd}/bin/systemctl suspend"; # sleep/suspend
          }
        ] ++ optional config.modules.desktop.niri.enable {
          timeout = toDesktopTimeout (60 + 30); # 1.5 min
          on-timeout = "niri msg action power-off-monitors";
        };
      };
    };
  };
}
