{ config, lib, pkgs, ... }:

with lib;
let
  cfg = config.modules.software.system.mpv;
in {
  options.modules.software.system.mpv = {
    enable = mkEnableOption "Enable mpv, a lightweight video player";
  };

  config = mkIf cfg.enable {
    hm.programs.mpv = {
      enable = true;

      config = {
        hwdec = "auto";
        keep-open = "yes";
        no-keepaspect-window = ""; # tiling doesn't play nice..
        osc = "no";
        border = "no";
        gpu-context = "wayland"; # TODO: remove, forced by a regression
      };

      scriptOpts = {
        visualizer = {
          mode = "noalbumart";
        };
        modernz = with config.colorScheme.palette; {
          bottomhover = "no";
          hover_effect = ""; # these are weird lookin
          seekbarfg_color = "#${base0D}"; # blue is a sane default
        };
      };

      scripts = with pkgs.mpvScripts; [
        mpris
        modernz
        thumbfast
        visualizer
      ];
    };
  };
}
